@@ -4,44 +4,7 @@
 using namespace Rcpp;
 
 
-DataFrame untreated(
-    const double psi,
-    const NumericVector& time,
-    const IntegerVector& event,
-    const IntegerVector& treat,
-    const NumericVector& rx,
-    const NumericVector& censor_time,
-    const bool recensor,
-    const bool autoswitch) {
-
-  NumericVector u = time*((1 - rx) + rx*exp(psi));
-  NumericVector t_star = clone(u);
-  IntegerVector d_star = clone(event);
-
-  if (recensor) {
-    NumericVector c_star = pmin(censor_time, censor_time*exp(psi));
-
-    if (autoswitch) {
-      NumericVector rx1 = rx[treat == 1];
-      NumericVector rx0 = rx[treat == 0];
-      if (is_true(all(rx1 == 1))) c_star[treat == 1] = R_PosInf;
-      if (is_true(all(rx0 == 0))) c_star[treat == 0] = R_PosInf;
-    }
-
-    t_star = pmin(u, c_star);
-    d_star[c_star < u] = 0;
-  }
-
-  DataFrame result = DataFrame::create(
-    Named("t_star") = t_star,
-    Named("d_star") = d_star
-  );
-
-  return result;
-}
-
-
-double est_eqn(
+double est_psi_rpsftm(
     const double psi,
     const IntegerVector& stratum,
     const NumericVector& time,
@@ -52,24 +15,17 @@ double est_eqn(
     const double treat_modifier,
     const bool recensor,
     const bool autoswitch,
-    double target = 0) {
+    const double target) {
 
   DataFrame Sstar = untreated(psi*treat_modifier, time, event, treat, rx,
                               censor_time, recensor, autoswitch);
 
-  NumericVector t_star = Sstar["t_star"];
-  IntegerVector d_star = Sstar["d_star"];
+  Sstar.push_back(stratum, "stratum");
+  DataFrame df = lrtest(Sstar, "", "stratum", "treated", "t_star", "d_star", 
+                        0, 0);
 
-  DataFrame data = DataFrame::create(
-    Named("stratum") = stratum,
-    Named("treat") = treat,
-    Named("time") = t_star,
-    Named("event") = d_star);
-
-  DataFrame df = lrtest(data, "", "stratum", "treat", "time", "event", 0, 0);
-
-  double result = as<double>(df["logRankZ"]) - target;
-  return result;
+  double z = df["logRankZ"];
+  return z - target;
 }
 
 
@@ -87,7 +43,7 @@ List rpsftmcpp(const DataFrame data,
                const int n_eval_z = 100,
                const double treat_modifier = 1,
                const bool recensor = 1,
-               const bool admin_recensor_only = 0,
+               const bool admin_recensor_only = 1,
                const bool autoswitch = 1,
                const bool gridsearch = 0,
                const double alpha = 0.05,
@@ -97,19 +53,25 @@ List rpsftmcpp(const DataFrame data,
                const int n_boot = 1000,
                const int seed = NA_INTEGER) {
 
-  int i, j, k, l, n = data.nrow();
+  int i, j, k, n = data.nrow();
   int p = static_cast<int>(base_cov.size());
   if (p == 1 && (base_cov[0] == "" || base_cov[0] == "none")) p = 0;
 
-  IntegerVector stratumn(n);
   int p_stratum = static_cast<int>(stratum.size());
+  
+  bool has_stratum;
+  IntegerVector stratumn(n);
+  DataFrame u_stratum;
   if (p_stratum == 1 && (stratum[0] == "" || stratum[0] == "none")) {
+    has_stratum = 0;
     stratumn.fill(1);
   } else {
     List out = bygroup(data, stratum);
+    has_stratum = 1;
     stratumn = out["index"];
+    u_stratum = DataFrame(out["lookup"]);
   }
-
+  
   bool has_time = hasVariable(data, time);
   bool has_event = hasVariable(data, event);
   bool has_treat = hasVariable(data, treat);
@@ -126,8 +88,8 @@ List rpsftmcpp(const DataFrame data,
 
   NumericVector timenz = data[time];
   NumericVector timen = clone(timenz);
-  if (is_true(any(timen <= 0))) {
-    stop("time must be positive");
+  if (is_true(any(timen < 0.0))) {
+    stop("time must be nonnegative");
   }
 
   if (!has_event) {
@@ -154,9 +116,12 @@ List rpsftmcpp(const DataFrame data,
 
   // create the numeric treat variable
   IntegerVector treatn(n);
+  IntegerVector treatwi;
+  NumericVector treatwn;
+  StringVector treatwc;
   if (TYPEOF(data[treat]) == LGLSXP || TYPEOF(data[treat]) == INTSXP) {
     IntegerVector treatv = data[treat];
-    IntegerVector treatwi = unique(treatv);
+    treatwi = unique(treatv);
     if (treatwi.size() != 2) {
       stop("treat must have two and only two distinct values");
     }
@@ -170,7 +135,7 @@ List rpsftmcpp(const DataFrame data,
     }
   } else if (TYPEOF(data[treat]) == REALSXP) {
     NumericVector treatv = data[treat];
-    NumericVector treatwn = unique(treatv);
+    treatwn = unique(treatv);
     if (treatwn.size() != 2) {
       stop("treat must have two and only two distinct values");
     }
@@ -184,7 +149,7 @@ List rpsftmcpp(const DataFrame data,
     }
   } else if (TYPEOF(data[treat]) == STRSXP) {
     StringVector treatv = data[treat];
-    StringVector treatwc = unique(treatv);
+    treatwc = unique(treatv);
     if (treatwc.size() != 2) {
       stop("treat must have two and only two distinct values");
     }
@@ -193,9 +158,9 @@ List rpsftmcpp(const DataFrame data,
   } else {
     stop("incorrect type for the treat variable in the input data");
   }
-
+  
   treatn = 2 - treatn; // use the 1/0 treatment coding
-
+  
   if (!has_rx) {
     stop("data must contain the rx variable");
   }
@@ -206,7 +171,7 @@ List rpsftmcpp(const DataFrame data,
 
   NumericVector rxnz = data[rx];
   NumericVector rxn = clone(rxnz);
-  if (is_true(any((rxn < 0) | (rxn > 1)))) {
+  if (is_true(any((rxn < 0.0) | (rxn > 1.0)))) {
     stop("rx must take values between 0 and 1");
   }
 
@@ -236,9 +201,8 @@ List rpsftmcpp(const DataFrame data,
   // covariates for the Cox proportional hazards model
   // containing treat and base_cov
   StringVector covariates(p+1);
-  NumericMatrix zn(n,p+1);
-  covariates[0] = "treat";
-  zn(_,0) = treatn;
+  NumericMatrix zn(n,p);
+  covariates[0] = "treated";
   for (j=0; j<p; j++) {
     String zj = base_cov[j];
     if (!hasVariable(data, zj)) {
@@ -249,7 +213,7 @@ List rpsftmcpp(const DataFrame data,
     }
     NumericVector u = data[zj];
     covariates[j+1] = zj;
-    zn(_,j+1) = u;
+    zn(_,j) = u;
   }
 
   if (low_psi >= hi_psi) {
@@ -260,11 +224,11 @@ List rpsftmcpp(const DataFrame data,
     stop("n_eval_z must be greater than or equal to 2");
   }
 
-  if (treat_modifier <= 0) {
+  if (treat_modifier <= 0.0) {
     stop("treat_modifier must be positive");
   }
 
-  if (alpha <= 0 || alpha >= 0.5) {
+  if (alpha <= 0.0 || alpha >= 0.5) {
     stop("alpha must lie between 0 and 0.5");
   }
   
@@ -272,21 +236,26 @@ List rpsftmcpp(const DataFrame data,
     stop("ties must be efron or breslow");
   }
   
+  if (tol <= 0.0) {
+    stop("tol must be positive");
+  }
+  
   if (n_boot < 100) {
     stop("n_boot must be greater than or equal to 100");
   }
 
+  
   DataFrame lr = lrtest(data, "", stratum, treat, time, event, 0, 0);
-  double logRankPValue = as<double>(lr["logRankPValue"]);
+  double logRankPValue = lr["logRankPValue"];
 
   // evaluate the log-rank test statistic at each psi
   double step_psi = (hi_psi - low_psi)/(n_eval_z - 1);
   NumericVector psi(n_eval_z), Z(n_eval_z);
   for (i=0; i<n_eval_z; i++) {
     psi[i] = low_psi + i*step_psi;
-    Z[i] = est_eqn(psi[i], stratumn, timen, eventn, treatn,
-                   rxn, censor_timen, treat_modifier,
-                   recensor, autoswitch, 0);
+    Z[i] = est_psi_rpsftm(psi[i], stratumn, timen, eventn, treatn,
+                          rxn, censor_timen, treat_modifier,
+                          recensor, autoswitch, 0);
   }
 
   DataFrame eval_z = DataFrame::create(
@@ -296,7 +265,8 @@ List rpsftmcpp(const DataFrame data,
   double zcrit = R::qnorm(1-alpha/2, 0, 1, 1, 0);
 
   k = -1;
-  auto f = [&k, n, p, covariates, low_psi, hi_psi, n_eval_z, psi, 
+  auto f = [&k, data, has_stratum, stratum, p_stratum, u_stratum, 
+            n, p, covariates, low_psi, hi_psi, n_eval_z, psi, 
             treat_modifier, recensor, autoswitch, gridsearch, 
             alpha, zcrit, ties, tol](
                 IntegerVector stratumb, NumericVector timeb,
@@ -312,10 +282,10 @@ List rpsftmcpp(const DataFrame data,
                   if (gridsearch) {
                     NumericVector Z(n_eval_z);
                     for (i=0; i<n_eval_z; i++) {
-                      Z[i] = est_eqn(psi[i], stratumb, timeb, eventb, 
-                                     treatb, rxb, censor_timeb, 
-                                     treat_modifier, recensor, 
-                                     autoswitch, 0);
+                      Z[i] = est_psi_rpsftm(
+                        psi[i], stratumb, timeb, eventb, treatb, 
+                        rxb, censor_timeb, treat_modifier, 
+                        recensor, autoswitch, 0);
                     }
 
                     auto g = [psi, Z](double target)->double{
@@ -336,10 +306,10 @@ List rpsftmcpp(const DataFrame data,
                     auto g = [&target, stratumb, timeb, eventb, treatb, 
                               rxb, censor_timeb, treat_modifier, recensor, 
                               autoswitch](double x)->double {
-                                return est_eqn(x, stratumb, timeb, eventb,
-                                               treatb, rxb, censor_timeb,
-                                               treat_modifier, recensor,
-                                               autoswitch, target);
+                                return est_psi_rpsftm(
+                                  x, stratumb, timeb, eventb, treatb, 
+                                  rxb, censor_timeb, treat_modifier, 
+                                  recensor, autoswitch, target);
                               };
 
                     psihat = brent(g, low_psi, hi_psi, tol);
@@ -353,74 +323,49 @@ List rpsftmcpp(const DataFrame data,
                     }
                   }
 
-                  // construct the counter-factual untreated survival times
-                  double psi1 = psihat*treat_modifier;
-                  DataFrame Sstar = untreated(psi1, timeb, eventb, treatb,
-                                              rxb, censor_timeb, recensor,
-                                              autoswitch);
-
-                  NumericVector t_star = Sstar["t_star"];
-                  IntegerVector d_star = Sstar["d_star"];
-
                   // obtain the Kaplan-Meier estimates
-                  DataFrame kmstar;
+                  DataFrame Sstar, kmstar;
                   if (k == -1) {
-                    DataFrame kmdata = DataFrame::create(
-                      Named("treat") = treatb,
-                      Named("time") = t_star,
-                      Named("event") = d_star);
+                    Sstar = untreated(
+                      psihat*treat_modifier, timeb, eventb, treatb,
+                      rxb, censor_timeb, recensor, autoswitch);
 
-                    kmstar = kmest(kmdata, "", "treat", "time",
-                                   "event", "log-log", 1-alpha);
+                    kmstar = kmest(Sstar, "", "treated", "t_star",
+                                   "d_star", "log-log", 1-alpha);
                   }
 
                   // run Cox model to obtain the hazard ratio estimate
-                  NumericVector rx1 = rxb[treatb == 1];
-                  bool switch1 = is_false(all(rx1 == 1));
-                  NumericVector timewb(n);
-                  IntegerVector eventwb(n);
-                  for (i=0; i<n; i++) {
-                    if (treatb[i] == 1) {
-                      if (switch1) {
-                        // counter-factual survival time on treatment
-                        double t_tilde, c_tilde;
-                        t_tilde = timeb[i]*((1-rxb[i])*exp(-psi1) + rxb[i]);
-                        if (recensor) {
-                          c_tilde = std::min(censor_timeb[i],
-                                             censor_timeb[i]*exp(-psi1));
-                          timewb[i] = std::min(t_tilde, c_tilde);
-                          eventwb[i] = c_tilde < t_tilde ? 0 : eventb[i];
-                        } else {
-                          timewb[i] = t_tilde;
-                          eventwb[i] = eventb[i];
-                        }
-                      } else {
-                        timewb[i] = timeb[i];
-                        eventwb[i] = eventb[i];
+                  DataFrame data_outcome = unswitched(
+                    psihat*treat_modifier, n, timeb, eventb, treatb,
+                    rxb, censor_timeb, recensor, autoswitch);
+
+                  if (has_stratum) {
+                    for (i=0; i<p_stratum; i++) {
+                      String s = stratum[i];
+                      if (TYPEOF(data[s]) == INTSXP) {
+                        IntegerVector stratumwi = u_stratum[s];
+                        data_outcome.push_back(stratumwi[stratumb-1], s);
+                      } else if (TYPEOF(data[s]) == REALSXP) {
+                        NumericVector stratumwn = u_stratum[s];
+                        data_outcome.push_back(stratumwn[stratumb-1], s);
+                      } else if (TYPEOF(data[s]) == STRSXP) {
+                        StringVector stratumwc = u_stratum[s];
+                        data_outcome.push_back(stratumwc[stratumb-1], s);
                       }
-                    } else {
-                      timewb[i] = t_star[i];
-                      eventwb[i] = d_star[i];
                     }
                   }
-
-                  DataFrame phdata = DataFrame::create(
-                    Named("stratum") = stratumb,
-                    Named("time") = timewb,
-                    Named("event") = eventwb,
-                    Named("treat") = treatb);
-
+                  
                   for (j=0; j<p; j++) {
                     String zj = covariates[j+1];
-                    NumericVector u = zb(_,j+1);
-                    phdata.push_back(u, zj);
+                    NumericVector u = zb(_,j);
+                    data_outcome.push_back(u, zj);
                   }
 
-                  List fit = phregcpp(phdata, "", "stratum", "time", "", 
-                                      "event", covariates, "", "", "", 
-                                      ties, 0, 0, 0, 0, 0, alpha);
+                  List fit_outcome = phregcpp(
+                    data_outcome, "", stratum, "t_star", "", "d_star", 
+                    covariates, "", "", "", ties, 0, 0, 0, 0, 0, alpha);
 
-                  DataFrame parest = DataFrame(fit["parest"]);
+                  DataFrame parest = DataFrame(fit_outcome["parest"]);
                   NumericVector beta = parest["beta"];
                   NumericVector z = parest["z"];
                   double hrhat = exp(beta[0]);
@@ -429,18 +374,19 @@ List rpsftmcpp(const DataFrame data,
                   List out;
                   if (k == -1) {
                     out = List::create(
+                      Named("Sstar") = Sstar,
+                      Named("kmstar") = kmstar,
+                      Named("data_outcome") = data_outcome,
+                      Named("fit_outcome") = fit_outcome,
                       Named("psihat") = psihat,
                       Named("psilower") = psilower,
                       Named("psiupper") = psiupper,
                       Named("psi_CI_type") = psi_CI_type,
-                      Named("Sstar") = Sstar,
-                      Named("kmstar") = kmstar,
                       Named("hrhat") = hrhat,
                       Named("pvalue") = pvalue);
                   } else {
                     out = List::create(
                       Named("psihat") = psihat,
-                      Named("psi_CI_type") = psi_CI_type,
                       Named("hrhat") = hrhat,
                       Named("pvalue") = pvalue);
                   }
@@ -450,15 +396,44 @@ List rpsftmcpp(const DataFrame data,
 
   List out = f(stratumn, timen, eventn, treatn, rxn, censor_timen, zn);
 
+  DataFrame Sstar = DataFrame(out["Sstar"]);
+  DataFrame kmstar = DataFrame(out["kmstar"]);
+  DataFrame data_outcome = DataFrame(out["data_outcome"]);
+  List fit_outcome = out["fit_outcome"];
   double psihat = out["psihat"];
   double psilower = out["psilower"];
   double psiupper = out["psiupper"];
   String psi_CI_type = out["psi_CI_type"];
-  DataFrame Sstar = DataFrame(out["Sstar"]);
-  DataFrame kmstar = DataFrame(out["kmstar"]);
   double hrhat = out["hrhat"];
   double pvalue = out["pvalue"];
-
+  
+  IntegerVector treated = Sstar["treated"];
+  if (TYPEOF(data[treat]) == LGLSXP || TYPEOF(data[treat]) == INTSXP) {
+    Sstar.push_back(treatwi[1-treated], treat);
+  } else if (TYPEOF(data[treat]) == REALSXP) {
+    Sstar.push_back(treatwn[1-treated], treat);
+  } else if (TYPEOF(data[treat]) == STRSXP) {
+    Sstar.push_back(treatwc[1-treated], treat);
+  }
+  
+  treated = kmstar["treated"];
+  if (TYPEOF(data[treat]) == LGLSXP || TYPEOF(data[treat]) == INTSXP) {
+    kmstar.push_back(treatwi[1-treated], treat);
+  } else if (TYPEOF(data[treat]) == REALSXP) {
+    kmstar.push_back(treatwn[1-treated], treat);
+  } else if (TYPEOF(data[treat]) == STRSXP) {
+    kmstar.push_back(treatwc[1-treated], treat);
+  }
+  
+  treated = data_outcome["treated"];
+  if (TYPEOF(data[treat]) == LGLSXP || TYPEOF(data[treat]) == INTSXP) {
+    data_outcome.push_back(treatwi[1-treated], treat);
+  } else if (TYPEOF(data[treat]) == REALSXP) {
+    data_outcome.push_back(treatwn[1-treated], treat);
+  } else if (TYPEOF(data[treat]) == STRSXP) {
+    data_outcome.push_back(treatwc[1-treated], treat);
+  }
+  
   // construct the confidence interval for HR
   double hrlower, hrupper;
   NumericVector hrhats(n_boot), psihats(n_boot);
@@ -475,7 +450,7 @@ List rpsftmcpp(const DataFrame data,
 
     IntegerVector stratumb(n), treatb(n), eventb(n);
     NumericVector timeb(n), rxb(n), censor_timeb(n);
-    NumericMatrix zb(n,p+1);
+    NumericMatrix zb(n,p);
 
     // sort data by treatment group
     IntegerVector idx0 = which(treatn == 0);
@@ -486,7 +461,6 @@ List rpsftmcpp(const DataFrame data,
     for (i=0; i<n0; i++) {
       order[i] = idx0[i];
     }
-
     for (i=0; i<n1; i++){
       order[n0+i] = idx1[i];
     }
@@ -515,12 +489,11 @@ List rpsftmcpp(const DataFrame data,
         treatb[i] = treatn[j];
         rxb[i] = rxn[j];
         censor_timeb[i] = censor_timen[j];
-        for (l=0; l<p+1; l++) {
-          zb(i,l) = zn(j,l);
-        }
+        zb(i,_) = zn(j,_);
       }
 
       List out = f(stratumb, timeb, eventb, treatb, rxb, censor_timeb, zb);
+      
       hrhats[k] = out["hrhat"];
       psihats[k] = out["psihat"];
     }
@@ -562,14 +535,16 @@ List rpsftmcpp(const DataFrame data,
     Named("psi") = psihat,
     Named("psi_CI") = NumericVector::create(psilower, psiupper),
     Named("psi_CI_type") = psi_CI_type,
-    Named("Sstar") = Sstar,
-    Named("kmstar") = kmstar,
-    Named("eval_z") = eval_z,
     Named("logrank_pvalue") = 2*std::min(logRankPValue, 1-logRankPValue),
     Named("cox_pvalue") = pvalue,
     Named("hr") = hrhat,
     Named("hr_CI") = NumericVector::create(hrlower, hrupper),
     Named("hr_CI_type") = hr_CI_type,
+    Named("eval_z") = eval_z,
+    Named("Sstar") = Sstar,
+    Named("kmstar") = kmstar,
+    Named("data_outcome") = data_outcome,
+    Named("fit_outcome") = fit_outcome,
     Named("settings") = settings);
 
   if (boot) {
